@@ -12,7 +12,7 @@ class Satellite(DataSourceOutput):
     """Class to store satellite data as a xr.Dataset with some validation"""
 
     __slots__ = ()
-    _expected_dimensions = ("time", "x", "y", "channels")
+    _expected_dimensions = ("time", "x_osgb", "y_osgb", "channels")
     _expected_data_vars = ("data",)
 
     @classmethod
@@ -22,7 +22,7 @@ class Satellite(DataSourceOutput):
         # previously nans were filled with -1s, so lets make sure there are none
         v.check_dataset_not_equal(data=v.data, value=-1)
         v.check_data_var_dim(
-            v.data, ("example", "time_index", "x_index", "y_index", "channels_index")
+            v.data, ("example", "time_index", "x_osgb_index", "y_osgb_index", "channels_index")
         )
 
         return v
@@ -32,5 +32,5 @@ class HRVSatellite(Satellite):
     """Class to store HRV satellite data as a xr.Dataset with some validation"""
 
     __slots__ = ()
-    _expected_dimensions = ("time", "x", "y", "channels")
+    _expected_dimensions = ("time", "x_osgb", "y_osgb", "channels")
     _expected_data_vars = ("data",)
